 ![](https://github.com/MrYsLab/s2aio/blob/master/images/happy.png)

Program, control and monitor an [Arduino](https://www.arduino.cc/) board using the [Scratch](scratch.mit.edu) or [Snap!](http://snap.berkeley.edu/) visual programming languages without having to learn C++. 

![](https://github.com/MrYsLab/s2aio/blob/master/images/examples/blink.png)

### **Included with s2aio are programming blocks** for the _**following languages**_:

[![Join the chat at https://gitter.im/MrYsLab/s2aio](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/MrYsLab/s2aio?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
* English (EN)
* Chinese (zh-CN)
* Chinese (zh-TW)
* Dutch (NL)
* French (FR)
* German (DE)
* Greek (GR)
* Korean (KO)
* Italian (IT)
* Portuguese (PT)
* Polish (PL)
* Spanish (ES)


### **Features**
* Written in Python using the new Python 3.5 asyncio library. 
* Cross platform - works with Windows, Mac and Linux (including Debian Raspberry Pi).
* Easy to install.
* Easy to use.

### Want to learn more? Check out the [Wiki pages](https://github.com/MrYsLab/s2aio/wiki).

This project was developed using [Pycharm](https://www.jetbrains.com/pycharm/) <a href="https://www.jetbrains.com/pycharm/">
  <img src="https://github.com/MrYsLab/python_banyan/blob/master/images/icon_PyCharm.png" alt="PyCharm" style="width:42px;height:42px;border:0">
</a>
